==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/sv.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard app",
    "Show something" : "Visa någonting",
    "Customize" : "Anpassa",
    "Edit widgets" : "Redigera gränssnittskomponenter",
    "Get more widgets from the app store" : "Hämta fler widgets från app store",
    "Change background image" : "Byt bakgrundsbild",
    "Weather service" : "Vädertjänst",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "För din integritet skull hämtas väderdata av din Nextcloud-server på dina vägnar så att vädertjänsten inte får någon personlig information.",
    "Weather data from Met.no" : "Väderdata från Met.no",
    "geocoding with Nominatim" : "geokodning med Nominatim",
    "elevation data from OpenTopoData" : "höjddata från OpenTopoData",
    "Weather" : "Väder",
    "Status" : "Status",
    "Good evening, {name}" : "God kväll, {name}",
    "Good evening" : "God kväll",
    "Good afternoon, {name}" : "God eftermiddag, {name}",
    "Good afternoon" : "God eftermiddag",
    "Good morning, {name}" : "God morgon, {name}",
    "Good morning" : "God morgon",
    "Good night, {name}" : "Godnatt, {name}",
    "Good night" : "Godnatt",
    "Pick from files" : "Välj från filer",
    "Default images" : "Standardbilder",
    "Plain background" : "Enkel bakgrund",
    "Insert from {productName}" : "Infoga från {productName}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.1-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/sv.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard app",
    "Show something" : "Visa någonting",
    "Customize" : "Anpassa",
    "Edit widgets" : "Redigera gränssnittskomponenter",
    "Get more widgets from the app store" : "Hämta fler widgets från app store",
    "Change background image" : "Byt bakgrundsbild",
    "Weather service" : "Vädertjänst",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "För din integritet skull hämtas väderdata av din Nextcloud-server på dina vägnar så att vädertjänsten inte får någon personlig information.",
    "Weather data from Met.no" : "Väderdata från Met.no",
    "geocoding with Nominatim" : "geokodning med Nominatim",
    "elevation data from OpenTopoData" : "höjddata från OpenTopoData",
    "Weather" : "Väder",
    "Status" : "Status",
    "Good morning" : "God morgon",
    "Good morning, {name}" : "God morgon, {name}",
    "Good afternoon" : "God eftermiddag",
    "Good afternoon, {name}" : "God eftermiddag, {name}",
    "Good evening" : "God kväll",
    "Good evening, {name}" : "God kväll, {name}",
    "Default images" : "Standardbilder",
    "Plain background" : "Enkel bakgrund",
    "Insert from {productName}" : "Infoga från {productName}",
    "Good night, {name}" : "Godnatt, {name}",
    "Good night" : "Godnatt",
    "Pick from files" : "Välj från filer"
},
"nplurals=2; plural=(n != 1);");
